@@ -8,34 +8,6 @@
 # Licence:  GPLv3 or later
 # --------------------------------------------------------------
 
-
-#' Fast estimation of demographic parameters
-#' 
-#' Jaatha is a composite maximum likelihood method to estimate parameters
-#' of a speciation model of closely related biological species out of SNP
-#' data.
-#' 
-#' @author
-#' Lisha Naduvilezhath \email{lisha (at) biologie.uni-muenchen.de},
-#' Paul R. Staab \email{staab (at) biologie.uni-muenchen.de} and 
-#' Dirk Metzler \email{metzler (at) biologie.uni-muenchen.de}
-#'
-#' Maintainer: Paul R. Staab \email{staab (at) biologie.uni-muenchen.de}
-#' @name jaatha-package
-#' @docType package
-#' @title Fast estimation of demographic parameters
-#' @keywords package
-#' @importFrom phyclust ms
-#' @importFrom foreach foreach 
-#' @importFrom foreach %do% 
-#' @importFrom methods new 
-#' @importFrom methods representation 
-#' @importFrom parallel mclapply
-#' @importFrom Rcpp evalCpp
-#' @importFrom dplyr as.tbl_cube
-#' @useDynLib jaatha
-NULL
-
 #' The "Jaatha" S4 class saves the basic parameters for a Jaatha estimation
 #' procedure
 #'
@@ -121,7 +93,6 @@ init <- function(.Object, sim.func, par.ranges,
     }
     else if (sum.stats[[i]]$method == "poisson.smoothing") {
       checkType(sum.stats[[i]]$model, c("char", "s"))      
-      stopifnot(length(dim(sum.stats[[i]]$value)) == 2)
       if (!is.null(sum.stats[[i]]$border.transformation)) {
         stopifnot(!is.null(sum.stats[[i]]$border.mask))
         sum.stats[[i]]$border.transformed <- 
@@ -223,34 +194,60 @@ Jaatha.initialize <- function(demographic.model, jsfs,
                        Manually move your complete R-tmp to your memory disk
                        instead. See http://www.paulstaab.de/2013/11/r-shm")
 
+  dm <- dm.addSummaryStatistic(demographic.model, 'jsfs')
+
   sum.stats <- list()
-  groups <- dm.getGroups(demographic.model)
+  seg.sites <- NULL
+  groups <- dm.getGroups(dm)
 
   for (group in groups) {
-    if (group == 1 & all(demographic.model@features$group == 0)) {
-      name <- 'jsfs'
+    if (group == 1 & all(dm@features$group == 0)) {
+      # Only one group of loci
+      jsfs.name <- 'jsfs'
       group <- 0
       if (is.list(jsfs)) { 
-        jsfs.cur <- jsfs$jsfs
+        jsfs.value <- jsfs$jsfs
+        seg.sites <- jsfs$seg.sites
       } else {
-        jsfs.cur <- jsfs
+        jsfs.value <- jsfs
       }
+
+      if (!is.null(seg.sites)) { 
+        dm <- dm.addSummaryStatistic(dm, 'fpc')
+        fpc.name <- 'fpc'
+        stopifnot(is.list(seg.sites))
+        stopifnot(is.array(seg.sites[[1]]))
+        dm <- calcFpcBreaks(dm, seg.sites)
+        fpc.value <- calcFpcSumStat(seg.sites, dm)
+      }
+
     } else {
-      name <- paste('jsfs', group, sep='.')
+      # Multiple groups of loci
+      jsfs.name <- paste('jsfs', group, sep='.')
       stopifnot(is.list(jsfs))
-      stopifnot(is.matrix(jsfs[[name]]))
-      jsfs.cur <- jsfs[[name]]
+      stopifnot(is.matrix(jsfs[[jsfs.name]]))
+      jsfs.value <- jsfs[[jsfs.name]]
+
+      seg.sites.name <- paste('seg.sites', group, sep='.')
+      if (is.list(jsfs[[seg.sites.name]])) {
+        seg.sites <- jsfs[[seg.sites.name]]
+        fpc.name <- paste('fpc', group, sep='.')
+        
+        dm <- dm.addSummaryStatistic(dm, 'fpc', group=group)
+        dm <- calcFpcBreaks(dm, seg.sites, group=group)
+        fpc.value <- calcFpcSumStat(seg.sites, dm, group=group)
+      }
     }
-    stopifnot(is.matrix(jsfs.cur))
+    stopifnot(is.matrix(jsfs.value))
 
     if (!smoothing) {
-      sum.stats[[name]] <- list(method="poisson.transformed",
-                                  transformation=summarizeJSFS,
-                                  value=jsfs.cur)
+      sum.stats[[jsfs.name]] <- list(method="poisson.transformed",
+                                     transformation=summarizeJSFS,
+                                     value=jsfs.value)
 
       if (folded) sum.stats$jsfs$transformation <- summarizeFoldedJSFS
     } else {
-      sample.size <- dm.getSampleSize(demographic.model, group)
+      sample.size <- dm.getSampleSize(dm, group)
       warning("Smoothing is still very experimental")
       model <- paste0("( X1 + I(X1^2) + X2 + I(X2^2) + log(X1) + log(",
                       sample.size[1]+2,
@@ -258,35 +255,54 @@ Jaatha.initialize <- function(demographic.model, jsfs,
                       sample.size[2]+2,
                       "-X2) )^2")
 
-      border.mask <- jsfs.cur
+      border.mask <- jsfs.value
       border.mask[, ] <- 0
-      border.mask[c(1, nrow(jsfs.cur)), ] <- 1
-      border.mask[ ,c(1, ncol(jsfs.cur))] <- 1
+      border.mask[c(1, nrow(jsfs.value)), ] <- 1
+      border.mask[ ,c(1, ncol(jsfs.value))] <- 1
       border.mask <- as.logical(border.mask)
 
-      sum.stats[[name]] <- list(method="poisson.smoothing",
-                                        model=model,
-                                        value=jsfs.cur,
-                                        border.transformation=summarizeJsfsBorder,
-                                        border.mask=border.mask)
+      sum.stats[[jsfs.name]] <- list(method="poisson.smoothing",
+                                     model=model,
+                                     value=jsfs.value,
+                                     border.mask=border.mask,
+                                     border.transformation=summarizeJsfsBorder)
+    }
+
+    if (!is.null(seg.sites)) { 
+      #border.mask <- fpc.value
+      #if (length(dim(border.mask)) == 2) {
+      #  border.mask[ , ] <- 0
+      #  border.mask[nrow(border.mask), ] <- 1
+      #  border.mask[ ,ncol(border.mask)] <- 1
+      #  fpc.model="(X1+I(X1^2)+X2+I(X2^2))^2"
+      #} else {
+      #  border.mask[ , , ] <- 0
+      #  border.mask[nrow(border.mask), , ] <- 1
+      #  border.mask[ ,ncol(border.mask), ] <- 1
+      #  fpc.model="(X1+I(X1^2)+X2+I(X2^2)+X3+I(X3^2))^2"
+      #}
+      sum.stats[[fpc.name]] <- list(method='poisson.transformed',
+                                    transformation=as.vector,
+                                    value=fpc.value)
     }
   }
 
   jaatha <- new("Jaatha", 
-                sim.func=function(sim.pars, jaatha)
-                  dm.simSumStats(jaatha@opts[['dm']], sim.pars, names(jaatha@sum.stats)), 
-                par.ranges=as.matrix(dm.getParRanges(demographic.model)),  
+                sim.func=function(sim.pars, jaatha) {
+                  dm.simSumStats(jaatha@opts[['dm']], sim.pars, names(jaatha@sum.stats))
+                },
+                par.ranges=as.matrix(dm.getParRanges(dm)),  
                 sum.stats=sum.stats,
                 seed=seed,
                 cores=cores,
                 use.shm=use.shm)
 
   if (scaling.factor != 1) {
-    demographic.model <- scaleDemographicModel(demographic.model, scaling.factor)
+    dm <- scaleDemographicModel(dm, scaling.factor)
     jaatha@opts[['scaling.factor']] <- scaling.factor
   }
 
-  jaatha@opts[['dm']] <- finalizeDM(demographic.model)
+  jaatha@opts[['dm']] <- dm.finalize(dm)
   jaatha@opts[['jsfs.folded']] <- folded
 
   return(jaatha)
