@@ -10,11 +10,15 @@
 ## -- Fixed bugs ----------------------------------------
 
 #print() failed for empty demographic models
-test.showEmptyModel <- function() {
+test.printEmptyDM <- function() {
   dm <- dm.createDemographicModel(25:26, 100)
   print(dm)
 }
 
+test.printGroupDM <- function() {
+  print(dm.grp)
+}
+
 test.ApeCodeInVignette <- function() {
   require('ape') || stop('Package "ape" is required for unit tests')
   sample.file <- system.file('example_fasta_files/sample.fasta', package='jaatha')
